eqcorrscan.core.match\_filter.detection.write\_catalog
======================================================

.. currentmodule:: eqcorrscan.core.match_filter.detection

.. autofunction:: write_catalog